Beacon class

Constructors

Beacon()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

attach(BeaconReceiver receiver) → void
Registers a new receiver
emit(String eventName, {Map<String, dynamic>? params}) → void
Emits an analytics event
shutdown() → void
Shuts down all receivers